from near_jsonrpc_models.rpc_call_function_request import RpcCallFunctionRequest
from pydantic import BaseModel
from typing import Literal


class JsonRpcRequestForExperimentalCallFunction(BaseModel):
    id: str
    jsonrpc: str
    method: Literal['EXPERIMENTAL_call_function']
    params: RpcCallFunctionRequest



"""Configuration for dynamic resharding feature"""

from pydantic import BaseModel
from pydantic import conint


class DynamicReshardingConfigView(BaseModel):
    # Maximum number of shards in the network.
    # 
    # See [`CongestionControlConfig`] for more details.
    max_number_of_shards: conint(ge=0, le=18446744073709551615)
    # Memory threshold over which a shard is marked for a split.
    # 
    # See [`CongestionControlConfig`] for more details.
    memory_usage_threshold: conint(ge=0, le=18446744073709551615)
    # Minimum memory usage of a child shard.
    # 
    # See [`CongestionControlConfig`] for more details.
    min_child_memory_usage: conint(ge=0, le=18446744073709551615)
    # Minimum number of epochs until next resharding can be scheduled.
    # 
    # See [`CongestionControlConfig`] for more details.
    min_epochs_between_resharding: conint(ge=0, le=18446744073709551615)



"""Lists access keys"""

from near_jsonrpc_models.access_key_info_view import AccessKeyInfoView
from pydantic import BaseModel
from typing import List


class AccessKeyList(BaseModel):
    keys: List[AccessKeyInfoView]



"""Auto-generated API mixin (generated by ApiGenerator).

This file contains APIMixinAsync which provides generated API methods.
The runtime provides a NearBaseClientAsync implementation (located in 'base_client')
that exposes `_call(...)`.
"""


from .base_client import NearBaseClientAsync

import near_jsonrpc_models


class APIMixinAsync:


    async def experimental_call_function(self: NearBaseClientAsync, *, params: near_jsonrpc_models.RpcCallFunctionRequest) -> near_jsonrpc_models.RpcCallFunctionResponse:
        """
        Calls a view function on a contract and returns the result.
        High-level method: returns the result model or raises NearClientError/NearRpcError/NearHttpError.
        """
        return await self._call(
            request_model=near_jsonrpc_models.JsonRpcRequestForExperimentalCallFunction,
            response_model=near_jsonrpc_models.JsonRpcResponseForRpcCallFunctionResponseAndRpcCallFunctionError,
            params=params,
        )

    async def experimental_changes(self: NearBaseClientAsync, *, params: near_jsonrpc_models.RpcStateChangesInBlockByTypeRequest) -> near_jsonrpc_models.RpcStateChangesInBlockResponse:
        """
        [Deprecated] Returns changes for a given account, contract or contract code for given block height or hash. Consider using changes instead.
        High-level method: returns the result model or raises NearClientError/NearRpcError/NearHttpError.
        """
        return await self._call(
            request_model=near_jsonrpc_models.JsonRpcRequestForExperimentalChanges,
            response_model=near_jsonrpc_models.JsonRpcResponseForRpcStateChangesInBlockResponseAndRpcStateChangesError,
            params=params,
        )

    async def experimental_changes_in_block(self: NearBaseClientAsync, *, params: near_jsonrpc_models.RpcStateChangesInBlockRequest) -> near_jsonrpc_models.RpcStateChangesInBlockByTypeResponse:
        """
        [Deprecated] Returns changes in block for given block height or hash over all transactions for all the types. Includes changes like account_touched, access_key_touched, data_touched, contract_code_touched. Consider using block_effects instead
        High-level method: returns the result model or raises NearClientError/NearRpcError/NearHttpError.
        """
        return await self._call(
            request_model=near_jsonrpc_models.JsonRpcRequestForExperimentalChangesInBlock,
            response_model=near_jsonrpc_models.JsonRpcResponseForRpcStateChangesInBlockByTypeResponseAndRpcStateChangesError,
            params=params,
        )

    async def experimental_congestion_level(self: NearBaseClientAsync, *, params: near_jsonrpc_models.RpcCongestionLevelRequest) -> near_jsonrpc_models.RpcCongestionLevelResponse:
        """
        Queries the congestion level of a shard. More info about congestion [here](https://near.github.io/nearcore/architecture/how/receipt-congestion.html?highlight=congestion#receipt-congestion)
        High-level method: returns the result model or raises NearClientError/NearRpcError/NearHttpError.
        """
        return await self._call(
            request_model=near_jsonrpc_models.JsonRpcRequestForExperimentalCongestionLevel,
            response_model=near_jsonrpc_models.JsonRpcResponseForRpcCongestionLevelResponseAndRpcChunkError,
            params=params,
        )

    async def experimental_genesis_config(self: NearBaseClientAsync) -> near_jsonrpc_models.GenesisConfig:
        """
        [Deprecated] Get initial state and parameters for the genesis block. Consider genesis_config instead.
        High-level method: returns the result model or raises NearClientError/NearRpcError/NearHttpError.
        """
        params = near_jsonrpc_models.GenesisConfigRequest.model_validate(None)
        return await self._call(
            request_model=near_jsonrpc_models.JsonRpcRequestForExperimentalGenesisConfig,
            response_model=near_jsonrpc_models.JsonRpcResponseForGenesisConfigAndGenesisConfigError,
            params=params,
        )

    async def experimental_light_client_block_proof(self: NearBaseClientAsync, *, params: near_jsonrpc_models.RpcLightClientBlockProofRequest) -> near_jsonrpc_models.RpcLightClientBlockProofResponse:
        """
        Returns the proofs for a transaction execution.
        High-level method: returns the result model or raises NearClientError/NearRpcError/NearHttpError.
        """
        return await self._call(
            request_model=near_jsonrpc_models.JsonRpcRequestForExperimentalLightClientBlockProof,
            response_model=near_jsonrpc_models.JsonRpcResponseForRpcLightClientBlockProofResponseAndRpcLightClientProofError,
            params=params,
        )

    async def experimental_light_client_proof(self: NearBaseClientAsync, *, params: near_jsonrpc_models.RpcLightClientExecutionProofRequest) -> near_jsonrpc_models.RpcLightClientExecutionProofResponse:
        """
        Returns the proofs for a transaction execution.
        High-level method: returns the result model or raises NearClientError/NearRpcError/NearHttpError.
        """
        return await self._call(
            request_model=near_jsonrpc_models.JsonRpcRequestForExperimentalLightClientProof,
            response_model=near_jsonrpc_models.JsonRpcResponseForRpcLightClientExecutionProofResponseAndRpcLightClientProofError,
            params=params,
        )

    async def experimental_maintenance_windows(self: NearBaseClientAsync, *, params: near_jsonrpc_models.RpcMaintenanceWindowsRequest) -> near_jsonrpc_models.JsonRpcResponseForArrayOfRangeOfUint64AndRpcMaintenanceWindowsError:
        """
        [Deprecated] Returns the future windows for maintenance in current epoch for the specified account. In the maintenance windows, the node will not be block producer or chunk producer. Consider using maintenance_windows instead.
        High-level method: returns the result model or raises NearClientError/NearRpcError/NearHttpError.
        """
        return await self._call(
            request_model=near_jsonrpc_models.JsonRpcRequestForExperimentalMaintenanceWindows,
            response_model=near_jsonrpc_models.JsonRpcResponseForArrayOfRangeOfUint64AndRpcMaintenanceWindowsError,
            params=params,
        )

    async def experimental_protocol_config(self: NearBaseClientAsync, *, params: near_jsonrpc_models.RpcProtocolConfigRequest) -> near_jsonrpc_models.RpcProtocolConfigResponse:
        """
        A configuration that defines the protocol-level parameters such as gas/storage costs, limits, feature flags, other settings
        High-level method: returns the result model or raises NearClientError/NearRpcError/NearHttpError.
        """
        return await self._call(
            request_model=near_jsonrpc_models.JsonRpcRequestForExperimentalProtocolConfig,
            response_model=near_jsonrpc_models.JsonRpcResponseForRpcProtocolConfigResponseAndRpcProtocolConfigError,
            params=params,
        )

    async def experimental_receipt(self: NearBaseClientAsync, *, params: near_jsonrpc_models.RpcReceiptRequest) -> near_jsonrpc_models.RpcReceiptResponse:
        """
        Fetches a receipt by its ID (as is, without a status or execution outcome)
        High-level method: returns the result model or raises NearClientError/NearRpcError/NearHttpError.
        """
        return await self._call(
            request_model=near_jsonrpc_models.JsonRpcRequestForExperimentalReceipt,
            response_model=near_jsonrpc_models.JsonRpcResponseForRpcReceiptResponseAndRpcReceiptError,
            params=params,
        )

    async def experimental_split_storage_info(self: NearBaseClientAsync, *, params: near_jsonrpc_models.RpcSplitStorageInfoRequest) -> near_jsonrpc_models.RpcSplitStorageInfoResponse:
        """
        Contains the split storage information. More info on split storage [here](https://near-nodes.io/archival/split-storage-archival)
        High-level method: returns the result model or raises NearClientError/NearRpcError/NearHttpError.
        """
        return await self._call(
            request_model=near_jsonrpc_models.JsonRpcRequestForExperimentalSplitStorageInfo,
            response_model=near_jsonrpc_models.JsonRpcResponseForRpcSplitStorageInfoResponseAndRpcSplitStorageInfoError,
            params=params,
        )

    async def experimental_tx_status(self: NearBaseClientAsync, *, params: near_jsonrpc_models.RpcTransactionStatusRequest) -> near_jsonrpc_models.RpcTransactionResponse:
        """
        Queries status of a transaction by hash, returning the final transaction result and details of all receipts.
        High-level method: returns the result model or raises NearClientError/NearRpcError/NearHttpError.
        """
        return await self._call(
            request_model=near_jsonrpc_models.JsonRpcRequestForExperimentalTxStatus,
            response_model=near_jsonrpc_models.JsonRpcResponseForRpcTransactionResponseAndRpcTransactionError,
            params=params,
        )

    async def experimental_validators_ordered(self: NearBaseClientAsync, *, params: near_jsonrpc_models.RpcValidatorsOrderedRequest) -> near_jsonrpc_models.JsonRpcResponseForArrayOfValidatorStakeViewAndRpcValidatorError:
        """
        Returns the current epoch validators ordered in the block producer order with repetition. This endpoint is solely used for bridge currently and is not intended for other external use cases.
        High-level method: returns the result model or raises NearClientError/NearRpcError/NearHttpError.
        """
        return await self._call(
            request_model=near_jsonrpc_models.JsonRpcRequestForExperimentalValidatorsOrdered,
            response_model=near_jsonrpc_models.JsonRpcResponseForArrayOfValidatorStakeViewAndRpcValidatorError,
            params=params,
        )

    async def experimental_view_access_key(self: NearBaseClientAsync, *, params: near_jsonrpc_models.RpcViewAccessKeyRequest) -> near_jsonrpc_models.RpcViewAccessKeyResponse:
        """
        Returns information about a single access key for given account.
        High-level method: returns the result model or raises NearClientError/NearRpcError/NearHttpError.
        """
        return await self._call(
            request_model=near_jsonrpc_models.JsonRpcRequestForExperimentalViewAccessKey,
            response_model=near_jsonrpc_models.JsonRpcResponseForRpcViewAccessKeyResponseAndRpcViewAccessKeyError,
            params=params,
        )

    async def experimental_view_access_key_list(self: NearBaseClientAsync, *, params: near_jsonrpc_models.RpcViewAccessKeyListRequest) -> near_jsonrpc_models.RpcViewAccessKeyListResponse:
        """
        Returns all access keys for a given account.
        High-level method: returns the result model or raises NearClientError/NearRpcError/NearHttpError.
        """
        return await self._call(
            request_model=near_jsonrpc_models.JsonRpcRequestForExperimentalViewAccessKeyList,
            response_model=near_jsonrpc_models.JsonRpcResponseForRpcViewAccessKeyListResponseAndRpcViewAccessKeyListError,
            params=params,
        )

    async def experimental_view_account(self: NearBaseClientAsync, *, params: near_jsonrpc_models.RpcViewAccountRequest) -> near_jsonrpc_models.RpcViewAccountResponse:
        """
        Returns information about an account for given account_id.
        High-level method: returns the result model or raises NearClientError/NearRpcError/NearHttpError.
        """
        return await self._call(
            request_model=near_jsonrpc_models.JsonRpcRequestForExperimentalViewAccount,
            response_model=near_jsonrpc_models.JsonRpcResponseForRpcViewAccountResponseAndRpcViewAccountError,
            params=params,
        )

    async def experimental_view_code(self: NearBaseClientAsync, *, params: near_jsonrpc_models.RpcViewCodeRequest) -> near_jsonrpc_models.RpcViewCodeResponse:
        """
        Returns the contract code (Wasm binary) deployed to the account.
        High-level method: returns the result model or raises NearClientError/NearRpcError/NearHttpError.
        """
        return await self._call(
            request_model=near_jsonrpc_models.JsonRpcRequestForExperimentalViewCode,
            response_model=near_jsonrpc_models.JsonRpcResponseForRpcViewCodeResponseAndRpcViewCodeError,
            params=params,
        )

    async def experimental_view_gas_key(self: NearBaseClientAsync, *, params: near_jsonrpc_models.RpcViewGasKeyRequest) -> near_jsonrpc_models.RpcViewGasKeyResponse:
        """
        Returns information about a single gas key for given account.
        High-level method: returns the result model or raises NearClientError/NearRpcError/NearHttpError.
        """
        return await self._call(
            request_model=near_jsonrpc_models.JsonRpcRequestForExperimentalViewGasKey,
            response_model=near_jsonrpc_models.JsonRpcResponseForRpcViewGasKeyResponseAndRpcViewGasKeyError,
            params=params,
        )

    async def experimental_view_gas_key_list(self: NearBaseClientAsync, *, params: near_jsonrpc_models.RpcViewGasKeyListRequest) -> near_jsonrpc_models.RpcViewGasKeyListResponse:
        """
        Returns all gas keys for a given account.
        High-level method: returns the result model or raises NearClientError/NearRpcError/NearHttpError.
        """
        return await self._call(
            request_model=near_jsonrpc_models.JsonRpcRequestForExperimentalViewGasKeyList,
            response_model=near_jsonrpc_models.JsonRpcResponseForRpcViewGasKeyListResponseAndRpcViewGasKeyListError,
            params=params,
        )

    async def experimental_view_state(self: NearBaseClientAsync, *, params: near_jsonrpc_models.RpcViewStateRequest) -> near_jsonrpc_models.RpcViewStateResponse:
        """
        Returns the state (key-value pairs) of a contract based on the key prefix.
        High-level method: returns the result model or raises NearClientError/NearRpcError/NearHttpError.
        """
        return await self._call(
            request_model=near_jsonrpc_models.JsonRpcRequestForExperimentalViewState,
            response_model=near_jsonrpc_models.JsonRpcResponseForRpcViewStateResponseAndRpcViewStateError,
            params=params,
        )

    async def block(self: NearBaseClientAsync, *, params: near_jsonrpc_models.RpcBlockRequest) -> near_jsonrpc_models.RpcBlockResponse:
        """
        Returns block details for given height or hash
        High-level method: returns the result model or raises NearClientError/NearRpcError/NearHttpError.
        """
        return await self._call(
            request_model=near_jsonrpc_models.JsonRpcRequestForBlock,
            response_model=near_jsonrpc_models.JsonRpcResponseForRpcBlockResponseAndRpcBlockError,
            params=params,
        )

    async def block_effects(self: NearBaseClientAsync, *, params: near_jsonrpc_models.RpcStateChangesInBlockRequest) -> near_jsonrpc_models.RpcStateChangesInBlockByTypeResponse:
        """
        Returns changes in block for given block height or hash over all transactions for all the types. Includes changes like account_touched, access_key_touched, data_touched, contract_code_touched.
        High-level method: returns the result model or raises NearClientError/NearRpcError/NearHttpError.
        """
        return await self._call(
            request_model=near_jsonrpc_models.JsonRpcRequestForBlockEffects,
            response_model=near_jsonrpc_models.JsonRpcResponseForRpcStateChangesInBlockByTypeResponseAndRpcStateChangesError,
            params=params,
        )

    async def broadcast_tx_async(self: NearBaseClientAsync, *, params: near_jsonrpc_models.RpcSendTransactionRequest) -> near_jsonrpc_models.CryptoHash:
        """
        [Deprecated] Sends a transaction and immediately returns transaction hash. Consider using send_tx instead.
        High-level method: returns the result model or raises NearClientError/NearRpcError/NearHttpError.
        """
        return await self._call(
            request_model=near_jsonrpc_models.JsonRpcRequestForBroadcastTxAsync,
            response_model=near_jsonrpc_models.JsonRpcResponseForCryptoHashAndRpcTransactionError,
            params=params,
        )

    async def broadcast_tx_commit(self: NearBaseClientAsync, *, params: near_jsonrpc_models.RpcSendTransactionRequest) -> near_jsonrpc_models.RpcTransactionResponse:
        """
        [Deprecated] Sends a transaction and waits until transaction is fully complete. (Has a 10 second timeout). Consider using send_tx instead.
        High-level method: returns the result model or raises NearClientError/NearRpcError/NearHttpError.
        """
        return await self._call(
            request_model=near_jsonrpc_models.JsonRpcRequestForBroadcastTxCommit,
            response_model=near_jsonrpc_models.JsonRpcResponseForRpcTransactionResponseAndRpcTransactionError,
            params=params,
        )

    async def changes(self: NearBaseClientAsync, *, params: near_jsonrpc_models.RpcStateChangesInBlockByTypeRequest) -> near_jsonrpc_models.RpcStateChangesInBlockResponse:
        """
        Returns changes for a given account, contract or contract code for given block height or hash.
        High-level method: returns the result model or raises NearClientError/NearRpcError/NearHttpError.
        """
        return await self._call(
            request_model=near_jsonrpc_models.JsonRpcRequestForChanges,
            response_model=near_jsonrpc_models.JsonRpcResponseForRpcStateChangesInBlockResponseAndRpcStateChangesError,
            params=params,
        )

    async def chunk(self: NearBaseClientAsync, *, params: near_jsonrpc_models.RpcChunkRequest) -> near_jsonrpc_models.RpcChunkResponse:
        """
        Returns details of a specific chunk. You can run a block details query to get a valid chunk hash.
        High-level method: returns the result model or raises NearClientError/NearRpcError/NearHttpError.
        """
        return await self._call(
            request_model=near_jsonrpc_models.JsonRpcRequestForChunk,
            response_model=near_jsonrpc_models.JsonRpcResponseForRpcChunkResponseAndRpcChunkError,
            params=params,
        )

    async def client_config(self: NearBaseClientAsync) -> near_jsonrpc_models.RpcClientConfigResponse:
        """
        Queries client node configuration
        High-level method: returns the result model or raises NearClientError/NearRpcError/NearHttpError.
        """
        params = near_jsonrpc_models.RpcClientConfigRequest.model_validate(None)
        return await self._call(
            request_model=near_jsonrpc_models.JsonRpcRequestForClientConfig,
            response_model=near_jsonrpc_models.JsonRpcResponseForRpcClientConfigResponseAndRpcClientConfigError,
            params=params,
        )

    async def gas_price(self: NearBaseClientAsync, *, params: near_jsonrpc_models.RpcGasPriceRequest) -> near_jsonrpc_models.RpcGasPriceResponse:
        """
        Returns gas price for a specific block_height or block_hash. Using [null] will return the most recent block's gas price.
        High-level method: returns the result model or raises NearClientError/NearRpcError/NearHttpError.
        """
        return await self._call(
            request_model=near_jsonrpc_models.JsonRpcRequestForGasPrice,
            response_model=near_jsonrpc_models.JsonRpcResponseForRpcGasPriceResponseAndRpcGasPriceError,
            params=params,
        )

    async def genesis_config(self: NearBaseClientAsync) -> near_jsonrpc_models.GenesisConfig:
        """
        Get initial state and parameters for the genesis block
        High-level method: returns the result model or raises NearClientError/NearRpcError/NearHttpError.
        """
        params = near_jsonrpc_models.GenesisConfigRequest.model_validate(None)
        return await self._call(
            request_model=near_jsonrpc_models.JsonRpcRequestForGenesisConfig,
            response_model=near_jsonrpc_models.JsonRpcResponseForGenesisConfigAndGenesisConfigError,
            params=params,
        )

    async def health(self: NearBaseClientAsync) -> near_jsonrpc_models.JsonRpcResponseForNullableRpcHealthResponseAndRpcStatusError:
        """
        Returns the current health status of the RPC node the client connects to.
        High-level method: returns the result model or raises NearClientError/NearRpcError/NearHttpError.
        """
        params = near_jsonrpc_models.RpcHealthRequest.model_validate(None)
        return await self._call(
            request_model=near_jsonrpc_models.JsonRpcRequestForHealth,
            response_model=near_jsonrpc_models.JsonRpcResponseForNullableRpcHealthResponseAndRpcStatusError,
            params=params,
        )

    async def light_client_proof(self: NearBaseClientAsync, *, params: near_jsonrpc_models.RpcLightClientExecutionProofRequest) -> near_jsonrpc_models.RpcLightClientExecutionProofResponse:
        """
        Returns the proofs for a transaction execution.
        High-level method: returns the result model or raises NearClientError/NearRpcError/NearHttpError.
        """
        return await self._call(
            request_model=near_jsonrpc_models.JsonRpcRequestForLightClientProof,
            response_model=near_jsonrpc_models.JsonRpcResponseForRpcLightClientExecutionProofResponseAndRpcLightClientProofError,
            params=params,
        )

    async def maintenance_windows(self: NearBaseClientAsync, *, params: near_jsonrpc_models.RpcMaintenanceWindowsRequest) -> near_jsonrpc_models.JsonRpcResponseForArrayOfRangeOfUint64AndRpcMaintenanceWindowsError:
        """
        Returns the future windows for maintenance in current epoch for the specified account. In the maintenance windows, the node will not be block producer or chunk producer.
        High-level method: returns the result model or raises NearClientError/NearRpcError/NearHttpError.
        """
        return await self._call(
            request_model=near_jsonrpc_models.JsonRpcRequestForMaintenanceWindows,
            response_model=near_jsonrpc_models.JsonRpcResponseForArrayOfRangeOfUint64AndRpcMaintenanceWindowsError,
            params=params,
        )

    async def network_info(self: NearBaseClientAsync) -> near_jsonrpc_models.RpcNetworkInfoResponse:
        """
        Queries the current state of node network connections. This includes information about active peers, transmitted data, known producers, etc.
        High-level method: returns the result model or raises NearClientError/NearRpcError/NearHttpError.
        """
        params = near_jsonrpc_models.RpcNetworkInfoRequest.model_validate(None)
        return await self._call(
            request_model=near_jsonrpc_models.JsonRpcRequestForNetworkInfo,
            response_model=near_jsonrpc_models.JsonRpcResponseForRpcNetworkInfoResponseAndRpcNetworkInfoError,
            params=params,
        )

    async def next_light_client_block(self: NearBaseClientAsync, *, params: near_jsonrpc_models.RpcLightClientNextBlockRequest) -> near_jsonrpc_models.RpcLightClientNextBlockResponse:
        """
        Returns the next light client block.
        High-level method: returns the result model or raises NearClientError/NearRpcError/NearHttpError.
        """
        return await self._call(
            request_model=near_jsonrpc_models.JsonRpcRequestForNextLightClientBlock,
            response_model=near_jsonrpc_models.JsonRpcResponseForRpcLightClientNextBlockResponseAndRpcLightClientNextBlockError,
            params=params,
        )

    async def query(self: NearBaseClientAsync, *, params: near_jsonrpc_models.RpcQueryRequest) -> near_jsonrpc_models.RpcQueryResponse:
        """
        This module allows you to make generic requests to the network.  The `RpcQueryRequest` struct takes in a [`BlockReference`](https://docs.rs/near-primitives/0.12.0/near_primitives/types/enum.BlockReference.html) and a [`QueryRequest`](https://docs.rs/near-primitives/0.12.0/near_primitives/views/enum.QueryRequest.html).  The `BlockReference` enum allows you to specify a block by `Finality`, `BlockId` or `SyncCheckpoint`.  The `QueryRequest` enum provides multiple variants for performing the following actions:  - View an account's details  - View a contract's code  - View the state of an account  - View the `AccessKey` of an account  - View the `AccessKeyList` of an account  - Call a function in a contract deployed on the network.
        High-level method: returns the result model or raises NearClientError/NearRpcError/NearHttpError.
        """
        return await self._call(
            request_model=near_jsonrpc_models.JsonRpcRequestForQuery,
            response_model=near_jsonrpc_models.JsonRpcResponseForRpcQueryResponseAndRpcQueryError,
            params=params,
        )

    async def send_tx(self: NearBaseClientAsync, *, params: near_jsonrpc_models.RpcSendTransactionRequest) -> near_jsonrpc_models.RpcTransactionResponse:
        """
        Sends transaction. Returns the guaranteed execution status and the results the blockchain can provide at the moment.
        High-level method: returns the result model or raises NearClientError/NearRpcError/NearHttpError.
        """
        return await self._call(
            request_model=near_jsonrpc_models.JsonRpcRequestForSendTx,
            response_model=near_jsonrpc_models.JsonRpcResponseForRpcTransactionResponseAndRpcTransactionError,
            params=params,
        )

    async def status(self: NearBaseClientAsync) -> near_jsonrpc_models.RpcStatusResponse:
        """
        Requests the status of the connected RPC node. This includes information about sync status, nearcore node version, protocol version, the current set of validators, etc.
        High-level method: returns the result model or raises NearClientError/NearRpcError/NearHttpError.
        """
        params = near_jsonrpc_models.RpcStatusRequest.model_validate(None)
        return await self._call(
            request_model=near_jsonrpc_models.JsonRpcRequestForStatus,
            response_model=near_jsonrpc_models.JsonRpcResponseForRpcStatusResponseAndRpcStatusError,
            params=params,
        )

    async def tx(self: NearBaseClientAsync, *, params: near_jsonrpc_models.RpcTransactionStatusRequest) -> near_jsonrpc_models.RpcTransactionResponse:
        """
        Queries status of a transaction by hash and returns the final transaction result.
        High-level method: returns the result model or raises NearClientError/NearRpcError/NearHttpError.
        """
        return await self._call(
            request_model=near_jsonrpc_models.JsonRpcRequestForTx,
            response_model=near_jsonrpc_models.JsonRpcResponseForRpcTransactionResponseAndRpcTransactionError,
            params=params,
        )

    async def validators(self: NearBaseClientAsync, *, params: near_jsonrpc_models.RpcValidatorRequest) -> near_jsonrpc_models.RpcValidatorResponse:
        """
        Queries active validators on the network. Returns details and the state of validation on the blockchain.
        High-level method: returns the result model or raises NearClientError/NearRpcError/NearHttpError.
        """
        return await self._call(
            request_model=near_jsonrpc_models.JsonRpcRequestForValidators,
            response_model=near_jsonrpc_models.JsonRpcResponseForRpcValidatorResponseAndRpcValidatorError,
            params=params,
        )



from near_jsonrpc_models.account_id import AccountId
from near_jsonrpc_models.crypto_hash import CryptoHash
from pydantic import BaseModel


class DataReceiverView(BaseModel):
    data_id: CryptoHash
    receiver_id: AccountId



from near_jsonrpc_models.rpc_view_gas_key_request import RpcViewGasKeyRequest
from pydantic import BaseModel
from typing import Literal


class JsonRpcRequestForExperimentalViewGasKey(BaseModel):
    id: str
    jsonrpc: str
    method: Literal['EXPERIMENTAL_view_gas_key']
    params: RpcViewGasKeyRequest



"""Information about this epoch validators and next epoch validators"""

from near_jsonrpc_models.current_epoch_validator_info import CurrentEpochValidatorInfo
from near_jsonrpc_models.next_epoch_validator_info import NextEpochValidatorInfo
from near_jsonrpc_models.validator_kickout_view import ValidatorKickoutView
from near_jsonrpc_models.validator_stake_view import ValidatorStakeView
from pydantic import BaseModel
from pydantic import conint
from typing import List


class RpcValidatorResponse(BaseModel):
    # Fishermen for the current epoch
    current_fishermen: List[ValidatorStakeView]
    # Proposals in the current epoch
    current_proposals: List[ValidatorStakeView]
    # Validators for the current epoch
    current_validators: List[CurrentEpochValidatorInfo]
    # Epoch height
    epoch_height: conint(ge=0, le=18446744073709551615)
    # Epoch start block height
    epoch_start_height: conint(ge=0, le=18446744073709551615)
    # Fishermen for the next epoch
    next_fishermen: List[ValidatorStakeView]
    # Validators for the next epoch
    next_validators: List[NextEpochValidatorInfo]
    # Kickout in the previous epoch
    prev_epoch_kickout: List[ValidatorKickoutView]



"""Wasmer0: Wasmer 0.17.x VM. Gone now.Wasmtime: Wasmtime VM.Wasmer2: Wasmer 2.x VM.NearVm: NearVM."""

from pydantic import RootModel
from typing import Literal


class VMKind(RootModel[Literal['Wasmer0', 'Wasmtime', 'Wasmer2', 'NearVm']]):
    pass




from near_jsonrpc_models.strict_model import StrictBaseModel
from pydantic import BaseModel
from pydantic import RootModel
from pydantic import conint
from typing import Literal
from typing import Union


"""String encoding is bad UTF-16 sequence"""
class HostErrorBadUTF16(RootModel[Literal['BadUTF16']]):
    pass

"""String encoding is bad UTF-8 sequence"""
class HostErrorBadUTF8(RootModel[Literal['BadUTF8']]):
    pass

"""Exceeded the prepaid gas"""
class HostErrorGasExceeded(RootModel[Literal['GasExceeded']]):
    pass

"""Exceeded the maximum amount of gas allowed to burn per contract"""
class HostErrorGasLimitExceeded(RootModel[Literal['GasLimitExceeded']]):
    pass

"""Exceeded the account balance"""
class HostErrorBalanceExceeded(RootModel[Literal['BalanceExceeded']]):
    pass

"""Tried to call an empty method name"""
class HostErrorEmptyMethodName(RootModel[Literal['EmptyMethodName']]):
    pass

class HostErrorGuestPanicPayload(BaseModel):
    panic_msg: str

class HostErrorGuestPanic(StrictBaseModel):
    """Smart contract panicked"""
    GuestPanic: HostErrorGuestPanicPayload

"""IntegerOverflow happened during a contract execution"""
class HostErrorIntegerOverflow(RootModel[Literal['IntegerOverflow']]):
    pass

class HostErrorInvalidPromiseIndexPayload(BaseModel):
    promise_idx: conint(ge=0, le=18446744073709551615)

class HostErrorInvalidPromiseIndex(StrictBaseModel):
    """`promise_idx` does not correspond to existing promises"""
    InvalidPromiseIndex: HostErrorInvalidPromiseIndexPayload

"""Actions can only be appended to non-joint promise."""
class HostErrorCannotAppendActionToJointPromise(RootModel[Literal['CannotAppendActionToJointPromise']]):
    pass

"""Returning joint promise is currently prohibited"""
class HostErrorCannotReturnJointPromise(RootModel[Literal['CannotReturnJointPromise']]):
    pass

class HostErrorInvalidPromiseResultIndexPayload(BaseModel):
    result_idx: conint(ge=0, le=18446744073709551615)

class HostErrorInvalidPromiseResultIndex(StrictBaseModel):
    """Accessed invalid promise result index"""
    InvalidPromiseResultIndex: HostErrorInvalidPromiseResultIndexPayload

class HostErrorInvalidRegisterIdPayload(BaseModel):
    register_id: conint(ge=0, le=18446744073709551615)

class HostErrorInvalidRegisterId(StrictBaseModel):
    """Accessed invalid register id"""
    InvalidRegisterId: HostErrorInvalidRegisterIdPayload

class HostErrorIteratorWasInvalidatedPayload(BaseModel):
    iterator_index: conint(ge=0, le=18446744073709551615)

class HostErrorIteratorWasInvalidated(StrictBaseModel):
    """Iterator `iterator_index` was invalidated after its creation by performing a mutable operation on trie"""
    IteratorWasInvalidated: HostErrorIteratorWasInvalidatedPayload

"""Accessed memory outside the bounds"""
class HostErrorMemoryAccessViolation(RootModel[Literal['MemoryAccessViolation']]):
    pass

class HostErrorInvalidReceiptIndexPayload(BaseModel):
    receipt_index: conint(ge=0, le=18446744073709551615)

class HostErrorInvalidReceiptIndex(StrictBaseModel):
    """VM Logic returned an invalid receipt index"""
    InvalidReceiptIndex: HostErrorInvalidReceiptIndexPayload

class HostErrorInvalidIteratorIndexPayload(BaseModel):
    iterator_index: conint(ge=0, le=18446744073709551615)

class HostErrorInvalidIteratorIndex(StrictBaseModel):
    """Iterator index `iterator_index` does not exist"""
    InvalidIteratorIndex: HostErrorInvalidIteratorIndexPayload

"""VM Logic returned an invalid account id"""
class HostErrorInvalidAccountId(RootModel[Literal['InvalidAccountId']]):
    pass

"""VM Logic returned an invalid method name"""
class HostErrorInvalidMethodName(RootModel[Literal['InvalidMethodName']]):
    pass

"""VM Logic provided an invalid public key"""
class HostErrorInvalidPublicKey(RootModel[Literal['InvalidPublicKey']]):
    pass

class HostErrorProhibitedInViewPayload(BaseModel):
    method_name: str

class HostErrorProhibitedInView(StrictBaseModel):
    """`method_name` is not allowed in view calls"""
    ProhibitedInView: HostErrorProhibitedInViewPayload

class HostErrorNumberOfLogsExceededPayload(BaseModel):
    limit: conint(ge=0, le=18446744073709551615)

class HostErrorNumberOfLogsExceeded(StrictBaseModel):
    """The total number of logs will exceed the limit."""
    NumberOfLogsExceeded: HostErrorNumberOfLogsExceededPayload

class HostErrorKeyLengthExceededPayload(BaseModel):
    length: conint(ge=0, le=18446744073709551615)
    limit: conint(ge=0, le=18446744073709551615)

class HostErrorKeyLengthExceeded(StrictBaseModel):
    """The storage key length exceeded the limit."""
    KeyLengthExceeded: HostErrorKeyLengthExceededPayload

class HostErrorValueLengthExceededPayload(BaseModel):
    length: conint(ge=0, le=18446744073709551615)
    limit: conint(ge=0, le=18446744073709551615)

class HostErrorValueLengthExceeded(StrictBaseModel):
    """The storage value length exceeded the limit."""
    ValueLengthExceeded: HostErrorValueLengthExceededPayload

class HostErrorTotalLogLengthExceededPayload(BaseModel):
    length: conint(ge=0, le=18446744073709551615)
    limit: conint(ge=0, le=18446744073709551615)

class HostErrorTotalLogLengthExceeded(StrictBaseModel):
    """The total log length exceeded the limit."""
    TotalLogLengthExceeded: HostErrorTotalLogLengthExceededPayload

class HostErrorNumberPromisesExceededPayload(BaseModel):
    limit: conint(ge=0, le=18446744073709551615)
    number_of_promises: conint(ge=0, le=18446744073709551615)

class HostErrorNumberPromisesExceeded(StrictBaseModel):
    """The maximum number of promises within a FunctionCall exceeded the limit."""
    NumberPromisesExceeded: HostErrorNumberPromisesExceededPayload

class HostErrorNumberInputDataDependenciesExceededPayload(BaseModel):
    limit: conint(ge=0, le=18446744073709551615)
    number_of_input_data_dependencies: conint(ge=0, le=18446744073709551615)

class HostErrorNumberInputDataDependenciesExceeded(StrictBaseModel):
    """The maximum number of input data dependencies exceeded the limit."""
    NumberInputDataDependenciesExceeded: HostErrorNumberInputDataDependenciesExceededPayload

class HostErrorReturnedValueLengthExceededPayload(BaseModel):
    length: conint(ge=0, le=18446744073709551615)
    limit: conint(ge=0, le=18446744073709551615)

class HostErrorReturnedValueLengthExceeded(StrictBaseModel):
    """The returned value length exceeded the limit."""
    ReturnedValueLengthExceeded: HostErrorReturnedValueLengthExceededPayload

class HostErrorContractSizeExceededPayload(BaseModel):
    limit: conint(ge=0, le=18446744073709551615)
    size: conint(ge=0, le=18446744073709551615)

class HostErrorContractSizeExceeded(StrictBaseModel):
    """The contract size for DeployContract action exceeded the limit."""
    ContractSizeExceeded: HostErrorContractSizeExceededPayload

class HostErrorDeprecatedPayload(BaseModel):
    method_name: str

class HostErrorDeprecated(StrictBaseModel):
    """The host function was deprecated."""
    Deprecated: HostErrorDeprecatedPayload

class HostErrorECRecoverErrorPayload(BaseModel):
    msg: str

class HostErrorECRecoverError(StrictBaseModel):
    """General errors for ECDSA recover."""
    ECRecoverError: HostErrorECRecoverErrorPayload

class HostErrorAltBn128InvalidInputPayload(BaseModel):
    msg: str

class HostErrorAltBn128InvalidInput(StrictBaseModel):
    """Invalid input to alt_bn128 family of functions (e.g., point which isn't
on the curve)."""
    AltBn128InvalidInput: HostErrorAltBn128InvalidInputPayload

class HostErrorEd25519VerifyInvalidInputPayload(BaseModel):
    msg: str

class HostErrorEd25519VerifyInvalidInput(StrictBaseModel):
    """Invalid input to ed25519 signature verification function (e.g. signature cannot be
derived from bytes)."""
    Ed25519VerifyInvalidInput: HostErrorEd25519VerifyInvalidInputPayload

class HostError(RootModel[Union[HostErrorBadUTF16, HostErrorBadUTF8, HostErrorGasExceeded, HostErrorGasLimitExceeded, HostErrorBalanceExceeded, HostErrorEmptyMethodName, HostErrorGuestPanic, HostErrorIntegerOverflow, HostErrorInvalidPromiseIndex, HostErrorCannotAppendActionToJointPromise, HostErrorCannotReturnJointPromise, HostErrorInvalidPromiseResultIndex, HostErrorInvalidRegisterId, HostErrorIteratorWasInvalidated, HostErrorMemoryAccessViolation, HostErrorInvalidReceiptIndex, HostErrorInvalidIteratorIndex, HostErrorInvalidAccountId, HostErrorInvalidMethodName, HostErrorInvalidPublicKey, HostErrorProhibitedInView, HostErrorNumberOfLogsExceeded, HostErrorKeyLengthExceeded, HostErrorValueLengthExceeded, HostErrorTotalLogLengthExceeded, HostErrorNumberPromisesExceeded, HostErrorNumberInputDataDependenciesExceeded, HostErrorReturnedValueLengthExceeded, HostErrorContractSizeExceeded, HostErrorDeprecated, HostErrorECRecoverError, HostErrorAltBn128InvalidInput, HostErrorEd25519VerifyInvalidInput]]):
    pass




"""Describes the permission scope for an access key. Whether it is a function call or a full access key."""

from near_jsonrpc_models.near_token import NearToken
from near_jsonrpc_models.strict_model import StrictBaseModel
from pydantic import BaseModel
from pydantic import RootModel
from typing import List
from typing import Literal
from typing import Union


class AccessKeyPermissionViewFullAccess(RootModel[Literal['FullAccess']]):
    pass

class AccessKeyPermissionViewFunctionCallPayload(BaseModel):
    allowance: NearToken | None = None
    method_names: List[str]
    receiver_id: str

class AccessKeyPermissionViewFunctionCall(StrictBaseModel):
    FunctionCall: AccessKeyPermissionViewFunctionCallPayload

class AccessKeyPermissionView(RootModel[Union[AccessKeyPermissionViewFullAccess, AccessKeyPermissionViewFunctionCall]]):
    pass




from near_jsonrpc_models.error_wrapper_for_rpc_status_error import ErrorWrapperForRpcStatusError
from near_jsonrpc_models.rpc_health_response import RpcHealthResponse
from pydantic import BaseModel
from pydantic import RootModel
from typing import Union


class JsonRpcResponseForNullableRpcHealthResponseAndRpcStatusErrorResult(BaseModel):
    id: str
    jsonrpc: str
    result: RpcHealthResponse | None

class JsonRpcResponseForNullableRpcHealthResponseAndRpcStatusErrorError(BaseModel):
    id: str
    jsonrpc: str
    error: ErrorWrapperForRpcStatusError

class JsonRpcResponseForNullableRpcHealthResponseAndRpcStatusError(RootModel[Union[JsonRpcResponseForNullableRpcHealthResponseAndRpcStatusErrorResult, JsonRpcResponseForNullableRpcHealthResponseAndRpcStatusErrorError]]):
    pass




from near_jsonrpc_models.duration_as_std_schema_provider import DurationAsStdSchemaProvider
from pydantic import BaseModel
from pydantic import conint


class EpochSyncConfig(BaseModel):
    # If true, even if the node started from genesis, it will not perform epoch sync.
    # There should be no reason to set this flag in production, because on both mainnet
    # and testnet it would be infeasible to catch up from genesis without epoch sync.
    disable_epoch_sync_for_bootstrapping: bool = False
    # This serves as two purposes: (1) the node will not epoch sync and instead resort to
    # header sync, if the genesis block is within this many blocks from the current block;
    # (2) the node will reject an epoch sync proof if the provided proof is for an epoch
    # that is more than this many blocks behind the current block.
    epoch_sync_horizon: conint(ge=0, le=18446744073709551615) = None
    # If true, the node will ignore epoch sync requests from the network. It is strongly
    # recommended not to set this flag, because it will prevent other nodes from
    # bootstrapping. This flag is only included as a kill-switch and may be removed in a
    # future release. Please note that epoch sync requests are heavily rate limited and
    # cached, and therefore should not affect the performance of the node or introduce
    # any non-negligible increase in network traffic.
    ignore_epoch_sync_network_requests: bool = False
    # Timeout for epoch sync requests. The node will continue retrying indefinitely even
    # if this timeout is exceeded.
    timeout_for_epoch_sync: DurationAsStdSchemaProvider = None



"""It is a [serializable view] of [`StateChangeKind`].

[serializable view]: ./index.html
[`StateChangeKind`]: ../types/struct.StateChangeKind.html"""

from near_jsonrpc_models.account_id import AccountId
from pydantic import BaseModel
from pydantic import RootModel
from typing import Literal
from typing import Union


class StateChangeKindViewAccountTouched(BaseModel):
    account_id: AccountId
    type: Literal['account_touched']

class StateChangeKindViewAccessKeyTouched(BaseModel):
    account_id: AccountId
    type: Literal['access_key_touched']

class StateChangeKindViewDataTouched(BaseModel):
    account_id: AccountId
    type: Literal['data_touched']

class StateChangeKindViewContractCodeTouched(BaseModel):
    account_id: AccountId
    type: Literal['contract_code_touched']

class StateChangeKindView(RootModel[Union[StateChangeKindViewAccountTouched, StateChangeKindViewAccessKeyTouched, StateChangeKindViewDataTouched, StateChangeKindViewContractCodeTouched]]):
    pass




from pydantic import BaseModel
from pydantic import RootModel
from typing import Literal
from typing import Union


class InternalErrorInternalErrorInfo(BaseModel):
    error_message: str

class InternalErrorInternalError(BaseModel):
    info: InternalErrorInternalErrorInfo
    name: Literal['INTERNAL_ERROR']

class InternalError(RootModel[Union[InternalErrorInternalError]]):
    pass




from near_jsonrpc_models.validator_stake_view_v1 import ValidatorStakeViewV1
from pydantic import BaseModel
from pydantic import RootModel
from typing import Literal
from typing import Union


class ValidatorStakeViewValidatorStakeStructVersion(ValidatorStakeViewV1):
    validator_stake_struct_version: Literal['V1']

class ValidatorStakeView(RootModel[Union[ValidatorStakeViewValidatorStakeStructVersion]]):
    pass




from near_jsonrpc_models.account_id import AccountId
from near_jsonrpc_models.block_id import BlockId
from near_jsonrpc_models.crypto_hash import CryptoHash
from near_jsonrpc_models.finality import Finality
from near_jsonrpc_models.function_args import FunctionArgs
from near_jsonrpc_models.public_key import PublicKey
from near_jsonrpc_models.store_key import StoreKey
from near_jsonrpc_models.sync_checkpoint import SyncCheckpoint
from pydantic import BaseModel
from pydantic import RootModel
from typing import Literal
from typing import Union


class RpcQueryRequestViewAccountByBlockId(BaseModel):
    block_id: BlockId
    account_id: AccountId
    request_type: Literal['view_account']

class RpcQueryRequestViewCodeByBlockId(BaseModel):
    block_id: BlockId
    account_id: AccountId
    request_type: Literal['view_code']

class RpcQueryRequestViewStateByBlockId(BaseModel):
    block_id: BlockId
    account_id: AccountId
    include_proof: bool = None
    prefix_base64: StoreKey
    request_type: Literal['view_state']

class RpcQueryRequestViewAccessKeyByBlockId(BaseModel):
    block_id: BlockId
    account_id: AccountId
    public_key: PublicKey
    request_type: Literal['view_access_key']

class RpcQueryRequestViewAccessKeyListByBlockId(BaseModel):
    block_id: BlockId
    account_id: AccountId
    request_type: Literal['view_access_key_list']

class RpcQueryRequestViewGasKeyByBlockId(BaseModel):
    block_id: BlockId
    account_id: AccountId
    public_key: PublicKey
    request_type: Literal['view_gas_key']

class RpcQueryRequestViewGasKeyListByBlockId(BaseModel):
    block_id: BlockId
    account_id: AccountId
    request_type: Literal['view_gas_key_list']

class RpcQueryRequestCallFunctionByBlockId(BaseModel):
    block_id: BlockId
    account_id: AccountId
    args_base64: FunctionArgs
    method_name: str
    request_type: Literal['call_function']

class RpcQueryRequestViewGlobalContractCodeByBlockId(BaseModel):
    block_id: BlockId
    code_hash: CryptoHash
    request_type: Literal['view_global_contract_code']

class RpcQueryRequestViewGlobalContractCodeByAccountIdByBlockId(BaseModel):
    block_id: BlockId
    account_id: AccountId
    request_type: Literal['view_global_contract_code_by_account_id']

class RpcQueryRequestViewAccountByFinality(BaseModel):
    finality: Finality
    account_id: AccountId
    request_type: Literal['view_account']

class RpcQueryRequestViewCodeByFinality(BaseModel):
    finality: Finality
    account_id: AccountId
    request_type: Literal['view_code']

class RpcQueryRequestViewStateByFinality(BaseModel):
    finality: Finality
    account_id: AccountId
    include_proof: bool = None
    prefix_base64: StoreKey
    request_type: Literal['view_state']

class RpcQueryRequestViewAccessKeyByFinality(BaseModel):
    finality: Finality
    account_id: AccountId
    public_key: PublicKey
    request_type: Literal['view_access_key']

class RpcQueryRequestViewAccessKeyListByFinality(BaseModel):
    finality: Finality
    account_id: AccountId
    request_type: Literal['view_access_key_list']

class RpcQueryRequestViewGasKeyByFinality(BaseModel):
    finality: Finality
    account_id: AccountId
    public_key: PublicKey
    request_type: Literal['view_gas_key']

class RpcQueryRequestViewGasKeyListByFinality(BaseModel):
    finality: Finality
    account_id: AccountId
    request_type: Literal['view_gas_key_list']

class RpcQueryRequestCallFunctionByFinality(BaseModel):
    finality: Finality
    account_id: AccountId
    args_base64: FunctionArgs
    method_name: str
    request_type: Literal['call_function']

class RpcQueryRequestViewGlobalContractCodeByFinality(BaseModel):
    finality: Finality
    code_hash: CryptoHash
    request_type: Literal['view_global_contract_code']

class RpcQueryRequestViewGlobalContractCodeByAccountIdByFinality(BaseModel):
    finality: Finality
    account_id: AccountId
    request_type: Literal['view_global_contract_code_by_account_id']

class RpcQueryRequestViewAccountBySyncCheckpoint(BaseModel):
    sync_checkpoint: SyncCheckpoint
    account_id: AccountId
    request_type: Literal['view_account']

class RpcQueryRequestViewCodeBySyncCheckpoint(BaseModel):
    sync_checkpoint: SyncCheckpoint
    account_id: AccountId
    request_type: Literal['view_code']

class RpcQueryRequestViewStateBySyncCheckpoint(BaseModel):
    sync_checkpoint: SyncCheckpoint
    account_id: AccountId
    include_proof: bool = None
    prefix_base64: StoreKey
    request_type: Literal['view_state']

class RpcQueryRequestViewAccessKeyBySyncCheckpoint(BaseModel):
    sync_checkpoint: SyncCheckpoint
    account_id: AccountId
    public_key: PublicKey
    request_type: Literal['view_access_key']

class RpcQueryRequestViewAccessKeyListBySyncCheckpoint(BaseModel):
    sync_checkpoint: SyncCheckpoint
    account_id: AccountId
    request_type: Literal['view_access_key_list']

class RpcQueryRequestViewGasKeyBySyncCheckpoint(BaseModel):
    sync_checkpoint: SyncCheckpoint
    account_id: AccountId
    public_key: PublicKey
    request_type: Literal['view_gas_key']

class RpcQueryRequestViewGasKeyListBySyncCheckpoint(BaseModel):
    sync_checkpoint: SyncCheckpoint
    account_id: AccountId
    request_type: Literal['view_gas_key_list']

class RpcQueryRequestCallFunctionBySyncCheckpoint(BaseModel):
    sync_checkpoint: SyncCheckpoint
    account_id: AccountId
    args_base64: FunctionArgs
    method_name: str
    request_type: Literal['call_function']

class RpcQueryRequestViewGlobalContractCodeBySyncCheckpoint(BaseModel):
    sync_checkpoint: SyncCheckpoint
    code_hash: CryptoHash
    request_type: Literal['view_global_contract_code']

class RpcQueryRequestViewGlobalContractCodeByAccountIdBySyncCheckpoint(BaseModel):
    sync_checkpoint: SyncCheckpoint
    account_id: AccountId
    request_type: Literal['view_global_contract_code_by_account_id']

class RpcQueryRequest(RootModel[Union[RpcQueryRequestViewAccountByBlockId, RpcQueryRequestViewCodeByBlockId, RpcQueryRequestViewStateByBlockId, RpcQueryRequestViewAccessKeyByBlockId, RpcQueryRequestViewAccessKeyListByBlockId, RpcQueryRequestViewGasKeyByBlockId, RpcQueryRequestViewGasKeyListByBlockId, RpcQueryRequestCallFunctionByBlockId, RpcQueryRequestViewGlobalContractCodeByBlockId, RpcQueryRequestViewGlobalContractCodeByAccountIdByBlockId, RpcQueryRequestViewAccountByFinality, RpcQueryRequestViewCodeByFinality, RpcQueryRequestViewStateByFinality, RpcQueryRequestViewAccessKeyByFinality, RpcQueryRequestViewAccessKeyListByFinality, RpcQueryRequestViewGasKeyByFinality, RpcQueryRequestViewGasKeyListByFinality, RpcQueryRequestCallFunctionByFinality, RpcQueryRequestViewGlobalContractCodeByFinality, RpcQueryRequestViewGlobalContractCodeByAccountIdByFinality, RpcQueryRequestViewAccountBySyncCheckpoint, RpcQueryRequestViewCodeBySyncCheckpoint, RpcQueryRequestViewStateBySyncCheckpoint, RpcQueryRequestViewAccessKeyBySyncCheckpoint, RpcQueryRequestViewAccessKeyListBySyncCheckpoint, RpcQueryRequestViewGasKeyBySyncCheckpoint, RpcQueryRequestViewGasKeyListBySyncCheckpoint, RpcQueryRequestCallFunctionBySyncCheckpoint, RpcQueryRequestViewGlobalContractCodeBySyncCheckpoint, RpcQueryRequestViewGlobalContractCodeByAccountIdBySyncCheckpoint]]):
    pass




from near_jsonrpc_models.rpc_block_request import RpcBlockRequest
from pydantic import BaseModel
from typing import Literal


class JsonRpcRequestForBlock(BaseModel):
    id: str
    jsonrpc: str
    method: Literal['block']
    params: RpcBlockRequest



from near_jsonrpc_models.genesis_config_request import GenesisConfigRequest
from pydantic import BaseModel
from typing import Literal


class JsonRpcRequestForGenesisConfig(BaseModel):
    id: str
    jsonrpc: str
    method: Literal['genesis_config']
    params: GenesisConfigRequest



from pydantic import BaseModel
from pydantic import RootModel
from typing import Literal
from typing import Union


class RpcValidatorErrorUnknownEpoch(BaseModel):
    name: Literal['UNKNOWN_EPOCH']

class RpcValidatorErrorValidatorInfoUnavailable(BaseModel):
    name: Literal['VALIDATOR_INFO_UNAVAILABLE']

class RpcValidatorErrorInternalErrorInfo(BaseModel):
    error_message: str

class RpcValidatorErrorInternalError(BaseModel):
    info: RpcValidatorErrorInternalErrorInfo
    name: Literal['INTERNAL_ERROR']

class RpcValidatorError(RootModel[Union[RpcValidatorErrorUnknownEpoch, RpcValidatorErrorValidatorInfoUnavailable, RpcValidatorErrorInternalError]]):
    pass




from near_jsonrpc_models.final_execution_outcome_view import FinalExecutionOutcomeView
from near_jsonrpc_models.final_execution_outcome_with_receipt_view import FinalExecutionOutcomeWithReceiptView
from near_jsonrpc_models.tx_execution_status import TxExecutionStatus
from pydantic import BaseModel
from pydantic import RootModel
from typing import Union


class RpcTransactionResponseFinalExecutionOutcomeWithReceiptView(FinalExecutionOutcomeWithReceiptView):
    final_execution_status: TxExecutionStatus

class RpcTransactionResponseFinalExecutionOutcomeView(FinalExecutionOutcomeView):
    final_execution_status: TxExecutionStatus

class RpcTransactionResponse(RootModel[Union[RpcTransactionResponseFinalExecutionOutcomeWithReceiptView, RpcTransactionResponseFinalExecutionOutcomeView]]):
    pass




from near_jsonrpc_models.block_id import BlockId
from near_jsonrpc_models.finality import Finality
from near_jsonrpc_models.sync_checkpoint import SyncCheckpoint
from pydantic import BaseModel
from pydantic import RootModel
from typing import Union


class RpcStateChangesInBlockRequestBlockId(BaseModel):
    block_id: BlockId

class RpcStateChangesInBlockRequestFinality(BaseModel):
    finality: Finality

class RpcStateChangesInBlockRequestSyncCheckpoint(BaseModel):
    sync_checkpoint: SyncCheckpoint

class RpcStateChangesInBlockRequest(RootModel[Union[RpcStateChangesInBlockRequestBlockId, RpcStateChangesInBlockRequestFinality, RpcStateChangesInBlockRequestSyncCheckpoint]]):
    pass




from near_jsonrpc_models.rpc_split_storage_info_request import RpcSplitStorageInfoRequest
from pydantic import BaseModel
from typing import Literal


class JsonRpcRequestForExperimentalSplitStorageInfo(BaseModel):
    id: str
    jsonrpc: str
    method: Literal['EXPERIMENTAL_split_storage_info']
    params: RpcSplitStorageInfoRequest



from near_jsonrpc_models.account_id import AccountId
from near_jsonrpc_models.prepare_error import PrepareError
from near_jsonrpc_models.strict_model import StrictBaseModel
from pydantic import BaseModel
from pydantic import RootModel
from typing import Union


class CompilationErrorCodeDoesNotExistPayload(BaseModel):
    account_id: AccountId

class CompilationErrorCodeDoesNotExist(StrictBaseModel):
    CodeDoesNotExist: CompilationErrorCodeDoesNotExistPayload

class CompilationErrorPrepareError(StrictBaseModel):
    PrepareError: PrepareError

class CompilationErrorWasmerCompileErrorPayload(BaseModel):
    msg: str

class CompilationErrorWasmerCompileError(StrictBaseModel):
    """This is for defense in depth.
We expect our runtime-independent preparation code to fully catch all invalid wasms,
but, if it ever misses something we’ll emit this error"""
    WasmerCompileError: CompilationErrorWasmerCompileErrorPayload

class CompilationError(RootModel[Union[CompilationErrorCodeDoesNotExist, CompilationErrorPrepareError, CompilationErrorWasmerCompileError]]):
    pass




from near_jsonrpc_models.account_id import AccountId
from near_jsonrpc_models.near_token import NearToken
from near_jsonrpc_models.public_key import PublicKey
from near_jsonrpc_models.strict_model import StrictBaseModel
from pydantic import BaseModel
from pydantic import RootModel
from typing import Literal
from typing import Union


class InvalidAccessKeyErrorAccessKeyNotFoundPayload(BaseModel):
    account_id: AccountId
    public_key: PublicKey

class InvalidAccessKeyErrorAccessKeyNotFound(StrictBaseModel):
    """The access key identified by the `public_key` doesn't exist for the account"""
    AccessKeyNotFound: InvalidAccessKeyErrorAccessKeyNotFoundPayload

class InvalidAccessKeyErrorReceiverMismatchPayload(BaseModel):
    ak_receiver: str
    tx_receiver: AccountId

class InvalidAccessKeyErrorReceiverMismatch(StrictBaseModel):
    """Transaction `receiver_id` doesn't match the access key receiver_id"""
    ReceiverMismatch: InvalidAccessKeyErrorReceiverMismatchPayload

class InvalidAccessKeyErrorMethodNameMismatchPayload(BaseModel):
    method_name: str

class InvalidAccessKeyErrorMethodNameMismatch(StrictBaseModel):
    """Transaction method name isn't allowed by the access key"""
    MethodNameMismatch: InvalidAccessKeyErrorMethodNameMismatchPayload

"""Transaction requires a full permission access key."""
class InvalidAccessKeyErrorRequiresFullAccess(RootModel[Literal['RequiresFullAccess']]):
    pass

class InvalidAccessKeyErrorNotEnoughAllowancePayload(BaseModel):
    account_id: AccountId
    allowance: NearToken
    cost: NearToken
    public_key: PublicKey

class InvalidAccessKeyErrorNotEnoughAllowance(StrictBaseModel):
    """Access Key does not have enough allowance to cover transaction cost"""
    NotEnoughAllowance: InvalidAccessKeyErrorNotEnoughAllowancePayload

"""Having a deposit with a function call action is not allowed with a function call access key."""
class InvalidAccessKeyErrorDepositWithFunctionCall(RootModel[Literal['DepositWithFunctionCall']]):
    pass

class InvalidAccessKeyError(RootModel[Union[InvalidAccessKeyErrorAccessKeyNotFound, InvalidAccessKeyErrorReceiverMismatch, InvalidAccessKeyErrorMethodNameMismatch, InvalidAccessKeyErrorRequiresFullAccess, InvalidAccessKeyErrorNotEnoughAllowance, InvalidAccessKeyErrorDepositWithFunctionCall]]):
    pass




from near_jsonrpc_models.internal_error import InternalError
from near_jsonrpc_models.rpc_request_validation_error_kind import RpcRequestValidationErrorKind
from near_jsonrpc_models.rpc_view_access_key_list_error import RpcViewAccessKeyListError
from pydantic import BaseModel
from pydantic import RootModel
from typing import Literal
from typing import Union


class ErrorWrapperForRpcViewAccessKeyListErrorRequestValidationError(BaseModel):
    cause: RpcRequestValidationErrorKind
    name: Literal['REQUEST_VALIDATION_ERROR']

class ErrorWrapperForRpcViewAccessKeyListErrorHandlerError(BaseModel):
    cause: RpcViewAccessKeyListError
    name: Literal['HANDLER_ERROR']

class ErrorWrapperForRpcViewAccessKeyListErrorInternalError(BaseModel):
    cause: InternalError
    name: Literal['INTERNAL_ERROR']

class ErrorWrapperForRpcViewAccessKeyListError(RootModel[Union[ErrorWrapperForRpcViewAccessKeyListErrorRequestValidationError, ErrorWrapperForRpcViewAccessKeyListErrorHandlerError, ErrorWrapperForRpcViewAccessKeyListErrorInternalError]]):
    pass




"""This action allows to execute the inner actions behalf of the defined sender."""

from near_jsonrpc_models.account_id import AccountId
from near_jsonrpc_models.non_delegate_action import NonDelegateAction
from near_jsonrpc_models.public_key import PublicKey
from pydantic import BaseModel
from pydantic import conint
from typing import List


class DelegateAction(BaseModel):
    # List of actions to be executed.
    # 
    # With the meta transactions MVP defined in NEP-366, nested
    # DelegateActions are not allowed. A separate type is used to enforce it.
    actions: List[NonDelegateAction]
    # The maximal height of the block in the blockchain below which the given DelegateAction is valid.
    max_block_height: conint(ge=0, le=18446744073709551615)
    # Nonce to ensure that the same delegate action is not sent twice by a
    # relayer and should match for given account's `public_key`.
    # After this action is processed it will increment.
    nonce: conint(ge=0, le=18446744073709551615)
    # Public key used to sign this delegated action.
    public_key: PublicKey
    # Receiver of the delegated actions.
    receiver_id: AccountId
    # Signer of the delegated actions
    sender_id: AccountId



"""A view of the contract code."""

from near_jsonrpc_models.crypto_hash import CryptoHash
from pydantic import BaseModel


class ContractCodeView(BaseModel):
    code_base64: str
    hash: CryptoHash



from near_jsonrpc_models.error_wrapper_for_genesis_config_error import ErrorWrapperForGenesisConfigError
from near_jsonrpc_models.genesis_config import GenesisConfig
from pydantic import BaseModel
from pydantic import RootModel
from typing import Union


class JsonRpcResponseForGenesisConfigAndGenesisConfigErrorResult(BaseModel):
    id: str
    jsonrpc: str
    result: GenesisConfig

class JsonRpcResponseForGenesisConfigAndGenesisConfigErrorError(BaseModel):
    id: str
    jsonrpc: str
    error: ErrorWrapperForGenesisConfigError

class JsonRpcResponseForGenesisConfigAndGenesisConfigError(RootModel[Union[JsonRpcResponseForGenesisConfigAndGenesisConfigErrorResult, JsonRpcResponseForGenesisConfigAndGenesisConfigErrorError]]):
    pass




"""Data structure for semver version and github tag or commit."""

from pydantic import BaseModel


class Version(BaseModel):
    build: str
    commit: str
    rustc_version: str = ''
    version: str



"""Contains main info about the block."""

from near_jsonrpc_models.crypto_hash import CryptoHash
from near_jsonrpc_models.near_token import NearToken
from near_jsonrpc_models.signature import Signature
from near_jsonrpc_models.slashed_validator import SlashedValidator
from near_jsonrpc_models.validator_stake_view import ValidatorStakeView
from pydantic import BaseModel
from pydantic import Field
from pydantic import conint
from typing import List


class BlockHeaderView(BaseModel):
    approvals: List[Signature | None]
    block_body_hash: CryptoHash | None = None
    block_merkle_root: CryptoHash
    block_ordinal: conint(ge=0, le=18446744073709551615) | None = None
    challenges_result: List[SlashedValidator]
    challenges_root: CryptoHash
    chunk_endorsements: List[List[conint(ge=0, le=255)]] | None = None
    chunk_headers_root: CryptoHash
    chunk_mask: List[bool]
    chunk_receipts_root: CryptoHash
    chunk_tx_root: CryptoHash
    chunks_included: conint(ge=0, le=18446744073709551615)
    epoch_id: CryptoHash
    epoch_sync_data_hash: CryptoHash | None = None
    gas_price: NearToken
    hash: CryptoHash
    height: conint(ge=0, le=18446744073709551615)
    last_ds_final_block: CryptoHash
    last_final_block: CryptoHash
    latest_protocol_version: conint(ge=0, le=4294967295)
    next_bp_hash: CryptoHash
    next_epoch_id: CryptoHash
    outcome_root: CryptoHash
    # The hash of the previous Block
    prev_hash: CryptoHash
    prev_height: conint(ge=0, le=18446744073709551615) | None = None
    prev_state_root: CryptoHash
    random_value: CryptoHash
    # TODO(2271): deprecated.
    rent_paid: NearToken = Field(default_factory=lambda: NearToken('0'))
    # Signature of the block producer.
    signature: Signature
    # Legacy json number. Should not be used.
    timestamp: conint(ge=0, le=18446744073709551615)
    timestamp_nanosec: str
    total_supply: NearToken
    validator_proposals: List[ValidatorStakeView]
    # TODO(2271): deprecated.
    validator_reward: NearToken = Field(default_factory=lambda: NearToken('0'))



from near_jsonrpc_models.error_wrapper_for_rpc_light_client_next_block_error import ErrorWrapperForRpcLightClientNextBlockError
from near_jsonrpc_models.rpc_light_client_next_block_response import RpcLightClientNextBlockResponse
from pydantic import BaseModel
from pydantic import RootModel
from typing import Union


class JsonRpcResponseForRpcLightClientNextBlockResponseAndRpcLightClientNextBlockErrorResult(BaseModel):
    id: str
    jsonrpc: str
    result: RpcLightClientNextBlockResponse

class JsonRpcResponseForRpcLightClientNextBlockResponseAndRpcLightClientNextBlockErrorError(BaseModel):
    id: str
    jsonrpc: str
    error: ErrorWrapperForRpcLightClientNextBlockError

class JsonRpcResponseForRpcLightClientNextBlockResponseAndRpcLightClientNextBlockError(RootModel[Union[JsonRpcResponseForRpcLightClientNextBlockResponseAndRpcLightClientNextBlockErrorResult, JsonRpcResponseForRpcLightClientNextBlockResponseAndRpcLightClientNextBlockErrorError]]):
    pass




"""An Action that can be included in a transaction or receipt, excluding delegate actions. This type represents all possible action types except DelegateAction to prevent infinite recursion in meta-transactions."""

from near_jsonrpc_models.add_gas_key_action import AddGasKeyAction
from near_jsonrpc_models.add_key_action import AddKeyAction
from near_jsonrpc_models.create_account_action import CreateAccountAction
from near_jsonrpc_models.delete_account_action import DeleteAccountAction
from near_jsonrpc_models.delete_gas_key_action import DeleteGasKeyAction
from near_jsonrpc_models.delete_key_action import DeleteKeyAction
from near_jsonrpc_models.deploy_contract_action import DeployContractAction
from near_jsonrpc_models.deploy_global_contract_action import DeployGlobalContractAction
from near_jsonrpc_models.deterministic_state_init_action import DeterministicStateInitAction
from near_jsonrpc_models.function_call_action import FunctionCallAction
from near_jsonrpc_models.stake_action import StakeAction
from near_jsonrpc_models.strict_model import StrictBaseModel
from near_jsonrpc_models.transfer_action import TransferAction
from near_jsonrpc_models.transfer_to_gas_key_action import TransferToGasKeyAction
from near_jsonrpc_models.use_global_contract_action import UseGlobalContractAction
from pydantic import BaseModel
from pydantic import RootModel
from typing import Union


class NonDelegateActionCreateAccount(StrictBaseModel):
    """Create an (sub)account using a transaction `receiver_id` as an ID for
a new account ID must pass validation rules described here
<https://nomicon.io/DataStructures/Account>."""
    CreateAccount: CreateAccountAction

class NonDelegateActionDeployContract(StrictBaseModel):
    """Sets a Wasm code to a receiver_id"""
    DeployContract: DeployContractAction

class NonDelegateActionFunctionCall(StrictBaseModel):
    FunctionCall: FunctionCallAction

class NonDelegateActionTransfer(StrictBaseModel):
    Transfer: TransferAction

class NonDelegateActionStake(StrictBaseModel):
    Stake: StakeAction

class NonDelegateActionAddKey(StrictBaseModel):
    AddKey: AddKeyAction

class NonDelegateActionDeleteKey(StrictBaseModel):
    DeleteKey: DeleteKeyAction

class NonDelegateActionDeleteAccount(StrictBaseModel):
    DeleteAccount: DeleteAccountAction

class NonDelegateActionDeployGlobalContract(StrictBaseModel):
    DeployGlobalContract: DeployGlobalContractAction

class NonDelegateActionUseGlobalContract(StrictBaseModel):
    UseGlobalContract: UseGlobalContractAction

class NonDelegateActionDeterministicStateInit(StrictBaseModel):
    DeterministicStateInit: DeterministicStateInitAction

class NonDelegateActionAddGasKey(StrictBaseModel):
    AddGasKey: AddGasKeyAction

class NonDelegateActionDeleteGasKey(StrictBaseModel):
    DeleteGasKey: DeleteGasKeyAction

class NonDelegateActionTransferToGasKey(StrictBaseModel):
    TransferToGasKey: TransferToGasKeyAction

class NonDelegateAction(RootModel[Union[NonDelegateActionCreateAccount, NonDelegateActionDeployContract, NonDelegateActionFunctionCall, NonDelegateActionTransfer, NonDelegateActionStake, NonDelegateActionAddKey, NonDelegateActionDeleteKey, NonDelegateActionDeleteAccount, NonDelegateActionDeployGlobalContract, NonDelegateActionUseGlobalContract, NonDelegateActionDeterministicStateInit, NonDelegateActionAddGasKey, NonDelegateActionDeleteGasKey, NonDelegateActionTransferToGasKey]]):
    pass




from near_jsonrpc_models.rpc_maintenance_windows_request import RpcMaintenanceWindowsRequest
from pydantic import BaseModel
from typing import Literal


class JsonRpcRequestForMaintenanceWindows(BaseModel):
    id: str
    jsonrpc: str
    method: Literal['maintenance_windows']
    params: RpcMaintenanceWindowsRequest
